==> haskell-openpgp-asciiarmor-0.1.1-35-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-openpgp-asciiarmor.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: openpgp-asciiarmor
version: 0.1.1
id: openpgp-asciiarmor-0.1.1-KiXaieCD3QaHeVABiHbm2s
key: openpgp-asciiarmor-0.1.1-KiXaieCD3QaHeVABiHbm2s
license: ISC
copyright: 2012-2018 Clint Adams
maintainer: Clint Adams <clint@debian.org>
author: Clint Adams
homepage: http://floss.scru.org/openpgp-asciiarmor
synopsis: OpenPGP (RFC4880) ASCII Armor codec
description:
    OpenPGP (RFC4880) ASCII Armor codec
category: Codec, Data
abi: 478d8c4c470233db7ebefb4a28ac11af
exposed: True
exposed-modules:
    Codec.Encryption.OpenPGP.ASCIIArmor
    Codec.Encryption.OpenPGP.ASCIIArmor.Decode
    Codec.Encryption.OpenPGP.ASCIIArmor.Encode
    Codec.Encryption.OpenPGP.ASCIIArmor.Types
hidden-modules: Data.Digest.CRC24
                Codec.Encryption.OpenPGP.ASCIIArmor.Multipart
                Codec.Encryption.OpenPGP.ASCIIArmor.Utils
import-dirs: /usr/lib/ghc-8.6.5/site-local/openpgp-asciiarmor-0.1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/openpgp-asciiarmor-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/openpgp-asciiarmor-0.1.1
hs-libraries: HSopenpgp-asciiarmor-0.1.1-KiXaieCD3QaHeVABiHbm2s
depends:
    attoparsec-0.13.2.2-L0PhfJn0b3D3Qcx7KDBMXo base-4.12.0.0
    base64-bytestring-1.0.0.2-9hYbO3I2I9012gU046eVdX binary-0.8.6.0
    bytestring-0.10.8.2
haddock-interfaces: /usr/share/doc/haskell-openpgp-asciiarmor/html/openpgp-asciiarmor.haddock
haddock-html: /usr/share/doc/haskell-openpgp-asciiarmor/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-openpgp-asciiarmor-0.1.1-40-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-openpgp-asciiarmor.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: openpgp-asciiarmor
version: 0.1.1
id: openpgp-asciiarmor-0.1.1-JQumsxincdaB6CREB3YkyF
key: openpgp-asciiarmor-0.1.1-JQumsxincdaB6CREB3YkyF
license: ISC
copyright: 2012-2018 Clint Adams
maintainer: Clint Adams <clint@debian.org>
author: Clint Adams
homepage: http://floss.scru.org/openpgp-asciiarmor
synopsis: OpenPGP (RFC4880) ASCII Armor codec
description:
    OpenPGP (RFC4880) ASCII Armor codec
category: Codec, Data
abi: 73bde86e623aa225c3638b10947a3167
exposed: True
exposed-modules:
    Codec.Encryption.OpenPGP.ASCIIArmor
    Codec.Encryption.OpenPGP.ASCIIArmor.Decode
    Codec.Encryption.OpenPGP.ASCIIArmor.Encode
    Codec.Encryption.OpenPGP.ASCIIArmor.Types
hidden-modules: Data.Digest.CRC24
                Codec.Encryption.OpenPGP.ASCIIArmor.Multipart
                Codec.Encryption.OpenPGP.ASCIIArmor.Utils
import-dirs: /usr/lib/ghc-8.6.5/site-local/openpgp-asciiarmor-0.1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/openpgp-asciiarmor-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/openpgp-asciiarmor-0.1.1
hs-libraries: HSopenpgp-asciiarmor-0.1.1-JQumsxincdaB6CREB3YkyF
depends:
    attoparsec-0.13.2.2-IYmscZi60PM1VHlw2sOR1C base-4.12.0.0
    base64-bytestring-1.0.0.2-Bm9gqw70QXoBbkNHszCarm binary-0.8.6.0
    bytestring-0.10.8.2
haddock-interfaces: /usr/share/doc/haskell-openpgp-asciiarmor/html/openpgp-asciiarmor.haddock
haddock-html: /usr/share/doc/haskell-openpgp-asciiarmor/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
